<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>PanelScreenSaver</name>
    <message>
        <source>Panel Screensaver Global shorcut: &apos;%1&apos; cannot be registered</source>
        <translation>Klávesovou zkratku pro modul Šetřič obrazovky &apos;%1&apos; nelze zapsat</translation>
    </message>
</context>
</TS>